// Copyright 2024 Google LLC All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

locals {
  common_labels = {
    "application" : "mainframe-connector",
    "instance-id" : var.name,
  }
}

resource "google_cloud_run_v2_job" "mfc_connector_job" {
  name             = var.name
  location         = var.region
  labels           = merge(var.additional_labels, local.common_labels)

  template {
    parallelism = 1
    task_count = 1

    template {
      timeout                          = "3600s"
      service_account                  = var.service_account
      containers {
        image = "${var.container_registry}:${var.release}"

        env {
          name = "ARG_INPUT"
          value = var.input_gsuri
        }

        env {
          name = "ARG_COPYBOOK"
          value = var.copybook_gsuri
        }

        env {
          name = "ARG_OUTPUT"
          value = var.output_gsuri
        }

        dynamic "env" {
          for_each = (var.debug ? { BQSH_ROOT_LOGGER : "true" } : {})
          content {
            name  = env.key
            value = env.value
          }
        }

        command = [
          "bash",
          "/opt/mainframe-connector/transcode.sh",
        ]

        resources {
          limits = {
            memory : var.memory_limit,
            cpu : var.cpu_limit,
          }
        }
      }
    }
  }
}
