// Copyright 2023 Google LLC All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

variable "project" {
  description = "GCP project to deploy the Mainframe Connector service."
  type        = string
}

variable "connector_service_account_email" {
  description = <<-EOT
  The service account email to use for the Mainframe Connector service.
  e.g. mainframe-connector@my-project.iam.gserviceaccount.com
  EOT
  type        = string
}

variable "connector_transcode_job_account_email" {
  description = <<-EOT
  The service account email to use for the Mainframe Connector transcode job.
  e.g. mainframe-connector@my-project.iam.gserviceaccount.com
  EOT
  type        = string
}

variable "region" {
  description = "GCP region to deploy the Mainframe Connector service."
  type        = string
  default     = "us-central1"
}

variable "debug" {
  description = "Turn on debug logging."
  type        = bool
  default     = false
}

variable "instance_id" {
  description = "Instance ID to use. This should be set if you intend to deploy multiple instances of Mainframe Connector in the same GCP project."
  type        = string
  default     = "mf-connector"
}

variable "additional_labels" {
  description = "Additional labels to add to created resources where applicable."
  type        = map(string)
  default     = {}
}

variable "connector_service_ingress" {
  description = <<-EOT
  Ingress policy for the Mainframe Connector service.
  For information about ingress policies, see
  https://cloud.google.com/run/docs/securing/ingress.
  For valid annotation values and descriptions, see
  https://registry.terraform.io/providers/hashicorp/google/latest/docs/resources/cloud_run_v2_service#ingress.
  EOT
  type        = string
  default     = "INGRESS_TRAFFIC_INTERNAL_ONLY"
}
